@@ -12,19 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from selenium.webdriver.common.by import By
+from appium.webdriver.common.appiumby import AppiumBy
 
 
-class MobileBy(By):
-    IOS_PREDICATE = '-ios predicate string'
-    IOS_UIAUTOMATION = '-ios uiautomation'
-    IOS_CLASS_CHAIN = '-ios class chain'
-    ANDROID_UIAUTOMATOR = '-android uiautomator'
-    ANDROID_VIEWTAG = '-android viewtag'
-    ANDROID_DATA_MATCHER = '-android datamatcher'
-    ANDROID_VIEW_MATCHER = '-android viewmatcher'
-    # Deprecated
-    WINDOWS_UI_AUTOMATION = '-windows uiautomation'
-    ACCESSIBILITY_ID = 'accessibility id'
-    IMAGE = '-image'
-    CUSTOM = '-custom'
+class MobileBy(AppiumBy):
+    """
+    deprecated:: 2.1.0
+        Please use 'from appium.webdriver.common.appiumby import AppiumBy' instead of 'MobileBy'.
+    """
+
+    pass
